(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{4:function(e,t,a){e.exports=a(5)},5:function(e,t,a){"use strict";a.r(t);var n=a(2);n.a.events.addEventListener(n.a.RENDER_EVENT,(function(e){var t=e.detail,a=document.body.lastElementChild;a&&document.body.removeChild(a);var s=document.body.appendChild(document.createElement("div"));for(var i in t.args.div_style)s.style[i]=t.args.div_style[i];for(var r=function(e){var a=s.appendChild(document.createElement("img"));for(var i in t.args.img_style)a.style[i]=t.args.img_style[i];a.src=t.args.paths[e],t.args.titles.length>e&&(a.title=t.args.titles[e]),a.onclick=function(){n.a.setComponentValue(e)}},o=0;o<t.args.paths.length;o++)r(o);n.a.setFrameHeight()})),n.a.setComponentReady(),n.a.setFrameHeight()}},[[4,1,2]]]);
//# sourceMappingURL=main.b47addb1.chunk.js.map